==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/FLEETMARKUPRATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour FLEETMARKUPRATEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FLEETMARKUPRATEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETMARKUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FLEETMARKUPRATEID_Type", propOrder = {
    "fleetmarkupid",
    "organizationid",
    "startdate"
})
public class FLEETMARKUPRATEID_Type {

    @XmlElement(name = "FLEETMARKUPID", required = true)
    protected FLEETMARKUPID_Type fleetmarkupid;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Obtient la valeur de la propriété fleetmarkupid.
     * 
     * @return
     *     possible object is
     *     {@link FLEETMARKUPID_Type }
     *     
     */
    public FLEETMARKUPID_Type getFLEETMARKUPID() {
        return fleetmarkupid;
    }

    /**
     * Définit la valeur de la propriété fleetmarkupid.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETMARKUPID_Type }
     *     
     */
    public void setFLEETMARKUPID(FLEETMARKUPID_Type value) {
        this.fleetmarkupid = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété startdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Définit la valeur de la propriété startdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/FLEETMARKUPRATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for FLEETMARKUPRATEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FLEETMARKUPRATEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETMARKUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FLEETMARKUPRATEID_Type", propOrder = {
    "fleetmarkupid",
    "organizationid",
    "startdate"
})
public class FLEETMARKUPRATEID_Type {

    @XmlElement(name = "FLEETMARKUPID", required = true)
    protected FLEETMARKUPID_Type fleetmarkupid;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Gets the value of the fleetmarkupid property.
     * 
     * @return
     *     possible object is
     *     {@link FLEETMARKUPID_Type }
     *     
     */
    public FLEETMARKUPID_Type getFLEETMARKUPID() {
        return fleetmarkupid;
    }

    /**
     * Sets the value of the fleetmarkupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETMARKUPID_Type }
     *     
     */
    public void setFLEETMARKUPID(FLEETMARKUPID_Type value) {
        this.fleetmarkupid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}
